@@ -186,6 +186,7 @@ void tetrinet_inmessage (enum inmsg_type msgtype, char *data)
         list_issued = 0;
         up_chan_list_source = g_timeout_add (30000, (GSourceFunc) partyline_update_channel_list, NULL);
         partyline_joining_channel ("");
+        show_start_button ();
         break;
     case IN_DISCONNECT:
         if (!connected) {
@@ -412,7 +413,7 @@ void tetrinet_inmessage (enum inmsg_type msgtype, char *data)
                   gchar *line = nocolor (token);
                   gchar *aux;
                       
-                  if (list_issued > 0)
+                  if (list_enabled && (list_issued > 0))
                   {
                     if (*line == '(')
                     {
@@ -600,6 +601,7 @@ void tetrinet_inmessage (enum inmsg_type msgtype, char *data)
             commands_checkstate ();
             partyline_fmt (_("%c*** The game has %cstarted"),
                            TETRI_TB_C_BRIGHT_RED, TETRI_TB_BOLD);
+            show_stop_button ();
             /* switch to playerfields when game starts */
             show_fields_page ();
         }
@@ -625,6 +627,7 @@ void tetrinet_inmessage (enum inmsg_type msgtype, char *data)
             commands_checkstate ();
             partyline_fmt(_("%c*** The game is %cin progress"),
                           TETRI_TB_C_BRIGHT_RED, TETRI_TB_BOLD);;
+            show_stop_button ();
         }
         break;
     case IN_PAUSE:
@@ -654,6 +657,7 @@ void tetrinet_inmessage (enum inmsg_type msgtype, char *data)
         commands_checkstate ();
         partyline_fmt (_("%c*** The game has %cended"),
                        TETRI_TB_C_BRIGHT_RED, TETRI_TB_BOLD);
+        show_start_button ();
         /* go back to partyline when game ends */
         show_partyline_page ();
         break;
@@ -1745,18 +1749,26 @@ notfieldkey:
     else if (gdk_keyval_to_lower (keyval) == keys[K_DISCARD]) {
         tetrinet_specialkey(-1);
     }
-    else switch (keyval) {
-    case GDK_1: tetrinet_specialkey(1); break;
-    case GDK_2: tetrinet_specialkey(2); break;
-    case GDK_3: tetrinet_specialkey(3); break;
-    case GDK_4: tetrinet_specialkey(4); break;
-    case GDK_5: tetrinet_specialkey(5); break;
-    case GDK_6: tetrinet_specialkey(6); break;
-    default:
-        return FALSE;
+    else if (gdk_keyval_to_lower (keyval) == keys[K_SPECIAL1]) {
+	tetrinet_specialkey(1);
+    }
+    else if (gdk_keyval_to_lower (keyval) == keys[K_SPECIAL2]) {
+	tetrinet_specialkey(2);
+    }
+    else if (gdk_keyval_to_lower (keyval) == keys[K_SPECIAL3]) {
+	tetrinet_specialkey(3);
+    }
+    else if (gdk_keyval_to_lower (keyval) == keys[K_SPECIAL4]) {
+	tetrinet_specialkey(4);
+    }
+    else if (gdk_keyval_to_lower (keyval) == keys[K_SPECIAL5]) {
+	tetrinet_specialkey(5);
+    }
+    else if (gdk_keyval_to_lower (keyval) == keys[K_SPECIAL6]) {
+	tetrinet_specialkey(6);
     }
     tetris_drawcurrentblock ();
-    return TRUE;
+    return FALSE;
 }
 
 void tetrinet_upkey (int keyval)
